.. _contribute:

Contributing
============

Welcome to the contributor's corner! This section of the documentation is
devoted to explaining what you need to know in order to make a contribution to
:code:`stylo`. Since contributions come in all shapes and sizes we'll put some
links below just click on the one you feel matches you the most and it should
take you where you need to go.

- :ref:`contribute_how_to`
- :ref:`contribute_ref`

.. _contribute_how_to:

How do I ..?
------------

- How do I :ref:`contribute_tutorial_open_issue`?
- How do I :ref:`contribute_tutorial_fork_repository`?
- How do I :ref:`contribute_tutorial_devenv_setup`?


.. _contribute_ref:

Tell me more about ..
---------------------

- Tell me more about the :ref:`Documentation Build <contribute_ref_docs_build>`
- Tell me more about the :ref:`Branching Policy <contribute_ref_branching>`
- Tell me more about the :ref:`contribute_ref_code_style`
- Tell me more about the :ref:`Release Process <contribute_ref_release>`
- Tell me more about the :ref:`Setup.py file <contribute_ref_setup_py>`

Index
-----

.. toctree::
   :maxdepth: 2

   get-started/index
   reference/index
   tutorials/index

